pub struct ConnectableConnection {
pub from: ConnectableRef,
pub from_port: usize,
pub to: ConnectableRef,
pub to_port: usize,
pub kind: Kind,
}Expand description
A connection between two Connectable objects inside a track.
Fields
from: ConnectableReffrom_port: usizeto: ConnectableRefto_port: usizekind: KindTrait Implementations
Sourceimpl Clone for ConnectableConnection
impl Clone for ConnectableConnection
Sourcefn clone(&self) -> ConnectableConnection
fn clone(&self) -> ConnectableConnection
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConnectableConnection
impl Debug for ConnectableConnection
Sourceimpl<'de> Deserialize<'de> for ConnectableConnection
impl<'de> Deserialize<'de> for ConnectableConnection
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ConnectableConnection
Sourceimpl Hash for ConnectableConnection
impl Hash for ConnectableConnection
Sourceimpl PartialEq for ConnectableConnection
impl PartialEq for ConnectableConnection
Sourcefn eq(&self, other: &ConnectableConnection) -> bool
fn eq(&self, other: &ConnectableConnection) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ConnectableConnection
impl Serialize for ConnectableConnection
impl StructuralPartialEq for ConnectableConnection