Module history

Module history 

Structs

History
UndoEntry

Functions

create_inverse_action
Create an inverse action that will undo the given action Returns None if the action cannot be inverted
create_inverse_actions
should_record
Check if an action should be recorded in history