copy_inputs_to_shm

Function copy_inputs_to_shm 

pub unsafe fn copy_inputs_to_shm(
    inputs: &[Arc<AudioIO>],
    ptr: *mut u8,
    frames: usize,
)
Safety

ptr must point to a valid, initialized shared-memory layout with enough space for the configured number of input channels and frames samples. frames must not exceed the block size reserved in that layout.