copy_outputs_from_shm

Function copy_outputs_from_shm 

pub unsafe fn copy_outputs_from_shm(
    outputs: &[Arc<AudioIO>],
    ptr: *mut u8,
    frames: usize,
)
Safety

ptr must point to a valid, initialized shared-memory layout with enough space for the configured number of output channels and frames samples. Each output buffer must be writable and at least frames elements long.