pub fn drop_host(
mapping: &Option<ShmMapping>,
events: &Option<EventPair>,
child: &UnsafeMutex<Option<Child>>,
shm_name: &str,
)Expand description
Shared shutdown logic for the Drop impl of all OOP processors.
pub fn drop_host(
mapping: &Option<ShmMapping>,
events: &Option<EventPair>,
child: &UnsafeMutex<Option<Child>>,
shm_name: &str,
)Shared shutdown logic for the Drop impl of all OOP processors.