Module interfaces

Module interfaces 

Structs

ClassInfo
Information about a plugin class
ComponentHandler
Component handler that tracks parameter changes from the plugin GUI
FactoryInfo
Information about the plugin factory
HostPlugFrame
Host-side IPlugFrame implementation that tracks resize requests from the plugin
PluginFactory
Safe wrapper around VST3 plugin factory
PluginInstance
Safe wrapper around a VST3 plugin instance
Vst3GuiInfo
GUI capability information for a VST3 plugin

Functions

protected_call
Wrap a potentially-panicking plugin call in catch_unwind. Returns the closure’s result on success, or an error string if it panics.
pump_host_run_loop