pub struct PluginFactory { /* private fields */ }Expand description
Safe wrapper around VST3 plugin factory
Implementations
Sourceimpl PluginFactory
impl PluginFactory
Sourcepub fn from_module(bundle_path: &Path) -> Result<Self, String>
pub fn from_module(bundle_path: &Path) -> Result<Self, String>
Load a VST3 plugin bundle and create a factory
Sourcepub fn get_class_info(&self, index: i32) -> Option<ClassInfo>
pub fn get_class_info(&self, index: i32) -> Option<ClassInfo>
Get information about a plugin class using the trait
Sourcepub fn count_classes(&self) -> i32
pub fn count_classes(&self) -> i32
Count the number of classes using the trait
Sourcepub fn create_instance(
&self,
class_id: &[i8; 16],
) -> Result<PluginInstance, String>
pub fn create_instance( &self, class_id: &[i8; 16], ) -> Result<PluginInstance, String>
Create an instance of a plugin using the trait
pub fn create_edit_controller( &self, class_id: &[i8; 16], ) -> Result<ComPtr<IEditController>, String>